# Py-RPAutom

Py-RPAutom é uma biblioteca que nasceu para facilitar o desenvolvimento de robôs automatizados (RPA), uma vez que precisamos fazer vários códigos repetitivos para determinadas ações. Tem como objetivo facilitar a criação de processos automatizados via código. Criamos uma breve documentação explicando como utilizar recursos para automação web, desktop e recursos do sistema como cópia de arquivos ou criação de pastas. A documentação pode ser conferida [aqui](https://aranseiki.github.io/py-rpautom/).

Ainda, a biblioteca é feita originalmente em português para aumentar a inclusão da população brasileira. Mesmo que o inglês seja o idioma predominantes na área de tecnologia, essa não é a realidade da nossa população. Se o objetivo dessa biblioteca é facilitar o desenvolvimento de aplicações, não faz sentido criar uma barreira idiomática.

Tendo origem em 2019, a biblioteca foi desenvolvida de modo separado cada módulo para facilitação no desenvolvimento de projetos pessoais, mas incorporados rapidamenta ao desenvolvimento profissional. Em 2022, foi a consolidação dos três módulos básicos até então (web, desktop e utilitários do sistema), unificando-os e criando assim a sua primeira versão pública.

Essa biblioteca usa ferramentas populares para automação e testes como Selenium, pywinauto, openpyxl e pywin32.
